@@ -19,6 +19,7 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kprocess.h>
+#include <krun.h>
 #include <kwin.h>
 
 #include "setupdlg.h"
@@ -36,6 +37,8 @@ KBiff::KBiff(DCOPClient *client, QWidget *parent)
       status(0),
       statusChanged(true)
 {
+    setBackgroundMode(X11ParentRelative);
+
     setAutoResize(true);
     setMargin(0);
     setAlignment(AlignLeft | AlignTop);
@@ -94,7 +97,7 @@ void KBiff::processSetup(const KBiffSetup* setup, bool run)
     playSoundPath  = setup->getPlaySoundPath();
     notify         = setup->getNotify();
     dostatus       = setup->getStatus();
-
+    	
     // if we aren't going the status route, we should at least
     // provide a tooltip!
     if (dostatus == false)
@@ -148,6 +151,8 @@ void KBiff::setMailboxList(const QList<KBiffMailbox>& mailbox_list, unsigned int
         connect(monitor, SIGNAL(signal_noConn()), this, SLOT(displayPixmap()));
         connect(monitor, SIGNAL(signal_invalidLogin(const QString&)),
                 this, SLOT(invalidLogin(const QString&)));
+        connect(monitor, SIGNAL(signal_fetchMail(const QString&)),
+                this, SLOT(slotLaunchFetchClient(const QString&)));
         monitorList.append(monitor);
     }
     myMUTEX = false;
@@ -402,45 +407,45 @@ void KBiff::displayPixmap()
 
 void KBiff::currentStatus(const int num, const QString& the_mailbox, const KBiffMailState the_state)
 {
-    statusChanged = true;
-    // iterate through all saved notify dialogs to see if "our" one is
-    // currently being displayed
-    KBiffNotify *notify;
-    for (notify = notifyList.first();
-         notify != 0;
-          notify = notifyList.next())
+  statusChanged = true;
+  // iterate through all saved notify dialogs to see if "our" one is
+  // currently being displayed
+  KBiffNotify *notify;
+  for (notify = notifyList.first();
+       notify != 0;
+       notify = notifyList.next())
+  {
+    // if this one is not visible, delete it from the list.  the only
+    // way it will again become visible is if the haveNewMail slot
+    // gets triggered
+    if (notify->isVisible() == false)
     {
-        // if this one is not visible, delete it from the list.  the only
-        // way it will again become visible is if the haveNewMail slot
-        // gets triggered
-        if (notify->isVisible() == false)
-        {
-            notifyList.remove();
-        }
-        else
-        {
-            // if this box is visible (active), we see if it is the one
-            // we are looking for
-            if (notify->getMailbox() == the_mailbox)
-            {
-                // yep.  now, if there is new mail, we set the new number in
-                // the dialog.  if it is any other state, we remove this
-                // dialog from the list
-                switch (the_state)
-                {
-                case NewMail:
-                    notify->setNew(num);
-                    break;
-                case OldMail:
-                case NoMail:
-                case NoConn:
-                default:
-                    notifyList.remove();
-                    break;
-                }
-            }
-        }
+      notifyList.remove();
     }
+    else
+    {
+      // if this box is visible (active), we see if it is the one
+      // we are looking for
+      if (notify->getMailbox() == the_mailbox)
+      {
+        // yep.  now, if there is new mail, we set the new number in
+        // the dialog.  if it is any other state, we remove this
+        // dialog from the list
+        switch (the_state)
+        {
+          case NewMail:
+            notify->setNew(num);
+            break;
+          case OldMail:
+          case NoMail:
+          case NoConn:
+          default:
+            notifyList.remove();
+            break;
+        }
+      }
+    }
+  }
 }
 
 void KBiff::haveNewMail(const int num, const QString& the_mailbox)
@@ -666,63 +671,15 @@ bool KBiff::isRunning()
 
 void KBiff::executeCommand(const QString& command)
 {
-    /**
-     * The KProcess object expects the first param to be the
-     * command and every param after that to be the command's params.
-     * As a result, though, if you pass it a string with spaces in it,
-     * then it takes the first token of the string as the command
-     * and ignores the rest of it!  We need to pass all tokens from
-     * the command string on as individual parameters to get around
-     * this.
-     */
-    KProcess process;
-    int index, beg;
-    char param[60];
-    const char* pom=command.latin1();
-    index=0;
-    while(pom[index])
-    {
-        // simplyfies whitespaces
-        while(pom[index] && (pom[index]==' ' || (pom[index]>=9 && pom[index]<=13)))
-            index++;
+  kdDebug(0) << "KBiff::executeCommand(" << command << ")" << endl;
+    KRun::runCommand(command);
+}
 
-        beg=0;
-        if(pom[index]=='"')
-        {
-            index++;
-            while(pom[index] && pom[index]!='"')
-            {
-                if(pom[index]==92 && pom[index+1])   // '\'
-                    index++;
-                if(beg<59)
-                {
-                    param[beg]=pom[index];
-                    beg++;
-                }
-                index++;
-            }  
-            index++;
-        }    
-        else
-        {
-            while(pom[index] && pom[index]>' ')
-            {
-                if(pom[index]==92 && pom[index+1])   // '\'
-                    index++;
-                if(beg<59)
-                {
-                    param[beg]=pom[index];
-                    beg++;
-                }
-                index++;
-            }  
-        }    
-        param[beg]=0;  
-        if(beg)
-            process << param;  
-    }
-
-    process.start(KProcess::DontCare);
+void KBiff::slotLaunchFetchClient(const QString& fetchClient)
+{
+    kdDebug(0) << "KBiff::slotLaunchFetchClient(" << fetchClient << ")" << endl;
+    if (!fetchClient.isEmpty())
+        executeCommand(fetchClient);
 }
 
 void KBiff::slotLaunchMailClient()
