@@ -9,6 +9,8 @@
  */
 #include "kbiffmonitor.h"
 
+#include <kmessagebox.h>
+
 #include <sys/types.h>
 #ifndef __STRICT_ANSI__
 #define __STRICT_ANSI__
@@ -337,6 +339,8 @@ void KBiffMonitor::setMailbox(KBiffURL& url)
         nntp->setAsync(async);
         simpleURL = "nntp://" + server + "/" + mailbox;
     }
+
+    fetchCommand = url.searchPar("fetch");
 }
 
 void KBiffMonitor::setMailboxIsRead()
@@ -385,6 +389,10 @@ void KBiffMonitor::checkLocal()
     // get the information about this local mailbox
     QFileInfo mbox(mailbox);
 
+    // run external fetch client
+    if (!fetchCommand.isEmpty())
+        emit(signal_fetchMail(fetchCommand));
+
     // check if we have new mail
     determineState(mbox.size(), mbox.lastRead(), mbox.lastModified());
 }
@@ -394,6 +402,10 @@ void KBiffMonitor::checkMbox()
     // get the information about this local mailbox
     QFileInfo mbox(mailbox);
 
+    // run external fetch client
+    if (!fetchCommand.isEmpty())
+        emit(signal_fetchMail(fetchCommand));
+
     // see if the state has changed
     if ((mbox.lastModified() != lastModified) || (mbox.size() != lastSize))
     {
@@ -559,6 +571,10 @@ void KBiffMonitor::checkMaildir()
     // get the information about this local mailbox
     QDir mbox(mailbox);
 
+    // run external fetch client
+    if (!fetchCommand.isEmpty())
+        emit(signal_fetchMail(fetchCommand));
+
     // make sure the mailbox exists
     if (mbox.exists())
     {
@@ -573,8 +589,25 @@ void KBiffMonitor::checkMaildir()
             new_mailbox.setFilter(QDir::Files);
             cur_mailbox.setFilter(QDir::Files);
 
-            // get the number of messages in each
+            // determining "new" (or "unread") mail in maildir folders
+            // is a *little* tricky.  all mail in the 'new' folder are
+            // new, of course... but so is all mail in the 'cur'
+            // folder that doesn't have a ':2,[R|S]' after it.
             newCount = new_mailbox.count();
+
+            const QFileInfoList *cur_list = cur_mailbox.entryInfoList();
+            QFileInfoListIterator it(*cur_list);
+            QFileInfo *info;
+
+            static QRegExp suffix(":2,?R?S?$");
+            while ((info = it.current()))
+            {
+                if (info->fileName().findRev(suffix) == -1)
+                {
+                    newCount++;
+                }
+                ++it;
+            }
             int cur_count = cur_mailbox.count();
 
             // all messages in 'new' are new
@@ -738,6 +771,11 @@ void KBiffMonitor::checkMHdir()
     char the_buffer[MAXSTR];
     char *buffer = the_buffer;
 
+    // run external fetch client
+    if (!fetchCommand.isEmpty())
+        emit(signal_fetchMail(fetchCommand));
+
+
     // make sure the mailbox exists
     if (mbox.exists())
     {
@@ -869,7 +907,7 @@ void KBiffMonitor::determineState(unsigned int size)
             onStateChanged();
         }
 
-        emit(signal_currentStatus(newCount, simpleURL, mailState));
+        emit(signal_currentStatus(newCount, key, mailState));
         return;
     }
 
@@ -886,7 +924,7 @@ void KBiffMonitor::determineState(unsigned int size)
         new_lastSize = size;
         b_new_lastSize = true;
         newCount  = size - lastSize;
-        emit(signal_currentStatus(newCount, simpleURL, mailState));
+        emit(signal_currentStatus(newCount, key, mailState));
         return;
     }
 
@@ -899,7 +937,7 @@ void KBiffMonitor::determineState(unsigned int size)
         emit(signal_oldMail());
         emit(signal_oldMail(simpleURL));
 
-        emit(signal_currentStatus(newCount, simpleURL, mailState));
+        emit(signal_currentStatus(newCount, key, mailState));
         onStateChanged();
         return;
     }
@@ -917,7 +955,7 @@ void KBiffMonitor::determineState(unsigned int size)
         }
     }
 
-    emit(signal_currentStatus(newCount, simpleURL, mailState));
+    emit(signal_currentStatus(newCount, key, mailState));
 }
 
 void KBiffMonitor::determineState(KBiffUidlList uidl_list)
@@ -962,15 +1000,19 @@ void KBiffMonitor::determineState(KBiffUidlList uidl_list)
       new_uidlList = uidl_list;
       b_new_uidlList = true;
     }
+    // this is horrible.  it will reset kbiff to OldMail the very next
+    // time a pop3 mailbox is checked.  i don't know of a way around
+    // this, though :-(
     else if (mailState != OldMail)
     {
+      newCount = 0;
       mailState = OldMail;
       emit(signal_oldMail());
       emit(signal_oldMail(simpleURL));
       onStateChanged();
     }
   }
-  emit(signal_currentStatus(newCount, simpleURL, mailState));
+  emit(signal_currentStatus(newCount, key, mailState));
 }
 
 void KBiffMonitor::determineState(KBiffMailState state)
@@ -1006,7 +1048,7 @@ void KBiffMonitor::determineState(KBiffMailState state)
         emit(signal_noConn(simpleURL));
         onStateChanged();
     }
-    emit(signal_currentStatus(newCount, simpleURL, mailState));
+    emit(signal_currentStatus(newCount, key, mailState));
 }
 
 void KBiffMonitor::determineState(unsigned int size, const QDateTime& last_read, const QDateTime& last_modified)
@@ -1065,7 +1107,7 @@ void KBiffMonitor::determineState(unsigned int size, const QDateTime& last_read,
   // If we get to this point, then the state now is exactly the
   // same as the state when last we checked.  Do nothing at this
   // point.
-  emit(signal_currentStatus(newCount, simpleURL, mailState));
+  emit(signal_currentStatus(newCount, key, mailState));
 }
 
 /**
