@@ -334,6 +334,12 @@ signals:
     */
     void signal_noConn(const QString& mailbox);
 
+    /**
+     * This will get <CODE>emit</CODE>ed everytime mail will be
+     * fetched externally
+     */
+    void signal_fetchMail(const QString& fetchClient);
+
     /**
      * This will get <CODE>emit</CODE>ed everytime the mailbox
      * should be checked (determined by @ref #setPollInterval)
@@ -394,6 +400,7 @@ private:
     QString server;
     QString user;
     QString password;
+    QString fetchCommand;
     unsigned short int port;
     bool    preauth;
     bool    keepalive;
