@@ -41,6 +41,9 @@
 #include <kprocess.h>
 #include <krun.h>
 #include <kurllabel.h>
+#include <kwin.h>
+
+#include <kbiffcodec.h>
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -64,7 +67,7 @@ KBiffSetup::KBiffSetup(const QString& profile, bool secure)
     : KDialog(0, 0, true)
 {
   // set the icon just to be cute
-  setIcon(kapp->miniIcon());
+  KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
 
   // make sure the profile is *something*
   QString the_profile;
@@ -1149,6 +1152,24 @@ KBiffMailboxTab::KBiffMailboxTab(const QString& profile, QWidget *parent)
   checkStorePassword = new QCheckBox(i18n("S&tore password"), this);
   QPushButton *advanced_button = new QPushButton(i18n("&Advanced"), this);
 
+  // the command to run before polling
+  QGroupBox *fetch_box = new QGroupBox(this);
+  fetch_box->setTitle(i18n("Pre-&Polling Command"));
+  fetch_box->setColumnLayout(0, Qt::Vertical );
+  fetch_box->layout()->setSpacing(0);
+  fetch_box->layout()->setMargin(0);
+
+  checkFetchCommand = new QCheckBox(i18n("&Enable"), fetch_box);
+  editFetchCommand = new QLineEdit(fetch_box);
+  buttonBrowseFetchCommand = new QPushButton(i18n("Browse"), fetch_box);
+  QString whatsthis = i18n(
+      "This command shall be run <em>before</em> KBiff polls for new "
+      "mail.  It is useful for those people that want to download their "
+      "POP3 mail regularly using (for instance) 'fetchmail'");
+  QWhatsThis::add(checkFetchCommand, whatsthis);
+  QWhatsThis::add(editFetchCommand, whatsthis);
+  QWhatsThis::add(buttonBrowseFetchCommand, whatsthis);
+
   // connect all the signals
   connect(mailboxes, SIGNAL(selectionChanged(QListViewItem *)),
                      SLOT(slotMailboxSelected(QListViewItem *)));
@@ -1158,9 +1179,26 @@ KBiffMailboxTab::KBiffMailboxTab(const QString& profile, QWidget *parent)
                          SLOT(protocolSelected(int)));
   connect(buttonBrowse, SIGNAL(clicked()), SLOT(browse()));
   connect(advanced_button, SIGNAL(clicked()), SLOT(advanced()));
+  connect(buttonBrowseFetchCommand, SIGNAL(clicked()), SLOT(browseFetchCommand()));
+  connect(checkFetchCommand, SIGNAL(toggled(bool)), SLOT(enableFetchCommand(bool)));
 
   // NOW DO THE LAYOUT
-  QGridLayout *param_layout = new QGridLayout(7, 3, 12);
+  QHBoxLayout *fetch_command_layout = new QHBoxLayout(5);
+  fetch_command_layout->addWidget(editFetchCommand, 1);
+  fetch_command_layout->addWidget(buttonBrowseFetchCommand);
+
+  QVBoxLayout *group_layout = new QVBoxLayout(fetch_box->layout());
+  group_layout->setAlignment(Qt::AlignTop);
+  group_layout->setSpacing(6);
+  group_layout->setMargin(11);
+  group_layout->addWidget(checkFetchCommand);
+  group_layout->addLayout(fetch_command_layout);
+
+  QHBoxLayout *advanced_layout = new QHBoxLayout;
+  advanced_layout->addStretch(1);
+  advanced_layout->addWidget(advanced_button);
+
+  QGridLayout *param_layout = new QGridLayout(6, 3, 12);
   param_layout->addWidget(protocol_label, 0, 0);
   param_layout->addWidget(comboProtocol, 0, 1, 1);
   param_layout->addWidget(buttonBrowse, 0, 2);
@@ -1173,7 +1211,13 @@ KBiffMailboxTab::KBiffMailboxTab(const QString& profile, QWidget *parent)
   param_layout->addWidget(password_label, 4, 0);
   param_layout->addMultiCellWidget(editPassword, 4, 4, 1, 2);
   param_layout->addMultiCellWidget(checkStorePassword, 5, 5, 1, 2);
-  param_layout->addWidget(advanced_button, 6, 2);
+  param_layout->setColStretch(1, 1);
+
+  QVBoxLayout *right_side_layout = new QVBoxLayout;
+  right_side_layout->addLayout(param_layout);
+  right_side_layout->addWidget(fetch_box);
+  right_side_layout->addLayout(advanced_layout);
+  right_side_layout->addStretch(1);
 
   QGridLayout *mailbox_layout = new QGridLayout(2, 2, 1);
   mailbox_layout->addMultiCellWidget(mailboxes, 0, 0, 0, 1);
@@ -1182,7 +1226,7 @@ KBiffMailboxTab::KBiffMailboxTab(const QString& profile, QWidget *parent)
 
   QHBoxLayout *top_layout = new QHBoxLayout(this, 12);
   top_layout->addLayout(mailbox_layout);
-  top_layout->addLayout(param_layout);
+  top_layout->addLayout(right_side_layout);
 
   readConfig(profile);
 }
@@ -1218,7 +1262,7 @@ void KBiffMailboxTab::readConfig(const QString& profile)
       KBiffMailbox *mailbox = new KBiffMailbox();
       mailbox->key = *mailbox_list.at(i);
       mailbox->url = KBiffURL(*mailbox_list.at(i+1));
-      QString password(scramble(*mailbox_list.at(i+2), false));
+      QString password(KBiffCodecs::base64Decode(*mailbox_list.at(i+2)));
 
       if (password.isEmpty())
         mailbox->store = false;
@@ -1279,7 +1323,7 @@ void KBiffMailboxTab::saveConfig(const QString& profile)
 
         mailbox = mailboxHash->find(item_text);
 
-        QString password(scramble(mailbox->url.pass()));
+        QString password(KBiffCodecs::base64Encode(mailbox->url.pass().local8Bit()));
         KBiffURL url = mailbox->url;
         url.setPass("");
 
@@ -1295,6 +1339,28 @@ void KBiffMailboxTab::saveConfig(const QString& profile)
     delete config;
 }
 
+void KBiffMailboxTab::enableFetchCommand(bool enable)
+{
+  editFetchCommand->setEnabled(enable);
+  buttonBrowseFetchCommand->setEnabled(enable);
+}
+
+void KBiffMailboxTab::browseFetchCommand()
+{
+  KURL url = KFileDialog::getOpenURL();
+
+  if( url.isEmpty() )
+    return;
+
+  if( !url.isLocalFile() )
+  {
+    KMessageBox::sorry( 0L, i18n( "Only local files can be executed." ) );
+    return;
+  }
+
+  editFetchCommand->setText( url.path() );
+}
+
 void KBiffMailboxTab::setMailbox(const KBiffURL& url)
 {
     QString prot(url.protocol());
@@ -1344,6 +1410,10 @@ void KBiffMailboxTab::setMailbox(const KBiffURL& url)
     preauth = url.searchPar("preauth") == "yes" ? true : false;
     keepalive = url.searchPar("keepalive") == "yes" ? true : false;
     async = url.searchPar("async") == "yes" ? true : false;
+
+    QString fetch = url.searchPar("fetch");
+    checkFetchCommand->setChecked(!fetch.isEmpty());
+    editFetchCommand->setText(fetch);
 }
 
 const KBiffURL KBiffMailboxTab::getMailbox() const
@@ -1393,6 +1463,9 @@ const KBiffURL KBiffMailboxTab::getMailbox() const
         url.setSearchPar("timeout", QString().setNum(timeout));
     }
 
+    if (checkFetchCommand->isChecked() && !editFetchCommand->text().isEmpty())
+        url.setSearchPar("fetch", editFetchCommand->text());
+
     return url;
 }
 
@@ -1605,23 +1678,6 @@ void KBiffMailboxTab::advanced()
   }
 }
 
-const QString KBiffMailboxTab::scramble(const QString& password, bool encode)
-{
-    if (password.isEmpty())
-        return QString::null;
-
-    // #### HPB: Doesn't care about unicode strings
-    const char* pass_ptr = (const char*)password.ascii();
-    char *ptr = new char[strlen(password.ascii()) + 1];
-    char *ret_ptr = ptr;
-
-    while (*pass_ptr)
-        *ptr++ = encode ? (*(pass_ptr++) - 4) : (*(pass_ptr++) + 4);
-    *ptr = '\0';
-
-    return ret_ptr;
-}
-
 const KBiffURL KBiffMailboxTab::defaultMailbox() const
 {
   QFileInfo mailbox_info(getenv("MAIL"));
@@ -1668,7 +1724,7 @@ KBiffAboutTab::KBiffAboutTab(QWidget *parent)
                       SLOT(homepage(const QString&)));
 
   QLabel *version_label = new QLabel(this);
-  version_label->setText(QString("Version %1\n\nCopyright (C) 1998-2001\nKurt Granroth").arg("3.4.2"));
+  version_label->setText(QString("Version %1\n\nCopyright (C) 1998-2001\nKurt Granroth").arg("3.5"));
 
   KURLLabel *email_label = new KURLLabel(this);
   email_label->setText("granroth@kde.org");
