@@ -32,9 +32,9 @@ class QComboBox;
 
 struct KBiffMailbox
 {
-	KBiffURL url;
-	bool store;
-	QString key;
+  KBiffURL url;
+  bool store;
+  QString key;
 };
 
 class KBiffGeneralTab;
@@ -235,8 +235,10 @@ protected slots:
 	void browse();
 	void advanced();
 
+	void enableFetchCommand(bool);
+	void browseFetchCommand();
+
 protected:
-	const QString scramble(const QString & password, bool encode = true);
 	const KBiffURL defaultMailbox() const;
 
 private:
@@ -253,9 +255,13 @@ private:
 	QLineEdit   *editServer;
 	QLineEdit   *editUser;
 	QLineEdit   *editPassword;
+	QLineEdit   *editFetchCommand;
+	QCheckBox   *checkFetchCommand;
 	QCheckBox   *checkStorePassword;
 	QPushButton *buttonBrowse;
 	QListView   *mailboxes;
+
+	QPushButton *buttonBrowseFetchCommand;
 };
 
 class KBiffAboutTab : public QWidget
