@@ -10,14 +10,14 @@
 #include "status.h"
 
 #include <kapp.h>
-
-#include <qlistview.h>
-#include <qheader.h>
-#include <qlayout.h>
-#include <qlabel.h>
-#include <qpoint.h>
 #include <klocale.h>
 
+#include <qheader.h>
+#include <qlabel.h>
+#include <qlayout.h>
+#include <qlistview.h>
+#include <qpoint.h>
+
 KBiffStatus::KBiffStatus(const QString& profile, const KBiffStatusList& list)
     : QFrame(0, 0, WStyle_Customize | WStyle_NoBorder),
       _listView(new QListView(this))
@@ -51,9 +51,9 @@ KBiffStatus::KBiffStatus(const QString& profile, const KBiffStatusList& list)
         }
     }
 
-    _listView->setMinimumSize(_listView->sizeHint());
     int list_height = (_listView->firstChild()->height() * list.count()) + 10;
-    _listView->setMinimumSize(_listView->sizeHint().width() + 5, list_height);
+    _listView->setFixedSize(_listView->sizeHint().width() + 5, list_height);
+    resize(_listView->size());
 
     QVBoxLayout *layout = new QVBoxLayout(this, 0, 0);
     layout->addWidget(profile_label);
